==> mastapy-14.0.0rc3-py3-none-any.whl: mastapy/_private/utility/units_and_measurements/measurements/_1711.py <==
"""InverseShortTime"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1655
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal import utility

_INVERSE_SHORT_TIME = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "InverseShortTime"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="InverseShortTime")
    CastSelf = TypeVar("CastSelf", bound="InverseShortTime._Cast_InverseShortTime")


__docformat__ = "restructuredtext en"
__all__ = ("InverseShortTime",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_InverseShortTime:
    """Special nested class for casting InverseShortTime to subclasses."""

    __parent__: "InverseShortTime"

    @property
    def measurement_base(self: "CastSelf") -> "_1655.MeasurementBase":
        return self.__parent__._cast(_1655.MeasurementBase)

    @property
    def inverse_short_time(self: "CastSelf") -> "InverseShortTime":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class InverseShortTime(_1655.MeasurementBase):
    """InverseShortTime

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _INVERSE_SHORT_TIME

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_InverseShortTime":
        """Cast to another type.

        Returns:
            _Cast_InverseShortTime
        """
        return _Cast_InverseShortTime(self)

==> mastapy-14.0.2-py3-none-any.whl: mastapy/_private/utility/units_and_measurements/measurements/_1711.py <==
"""Integer"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1657

_INTEGER = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "Integer"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Integer")
    CastSelf = TypeVar("CastSelf", bound="Integer._Cast_Integer")


__docformat__ = "restructuredtext en"
__all__ = ("Integer",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Integer:
    """Special nested class for casting Integer to subclasses."""

    __parent__: "Integer"

    @property
    def measurement_base(self: "CastSelf") -> "_1657.MeasurementBase":
        return self.__parent__._cast(_1657.MeasurementBase)

    @property
    def integer(self: "CastSelf") -> "Integer":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class Integer(_1657.MeasurementBase):
    """Integer

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _INTEGER

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_Integer":
        """Cast to another type.

        Returns:
            _Cast_Integer
        """
        return _Cast_Integer(self)
